==> gnome-vfs-2.6.1.1.tar.bz2: gnome-vfs-2.6.1.1/libgnomevfs/gnome-vfs-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __LIBGNOMEVFS_ENUM_TYPES_H__
#define __LIBGNOMEVFS_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "gnome-vfs-directory.h" */

GType gnome_vfs_directory_visit_options_get_type (void);
#define GNOME_VFS_TYPE_VFS_DIRECTORY_VISIT_OPTIONS (gnome_vfs_directory_visit_options_get_type())

/* enumerations from "gnome-vfs-file-info.h" */

GType gnome_vfs_file_flags_get_type (void);
#define GNOME_VFS_TYPE_VFS_FILE_FLAGS (gnome_vfs_file_flags_get_type())

GType gnome_vfs_file_type_get_type (void);
#define GNOME_VFS_TYPE_VFS_FILE_TYPE (gnome_vfs_file_type_get_type())

GType gnome_vfs_file_info_fields_get_type (void);
#define GNOME_VFS_TYPE_VFS_FILE_INFO_FIELDS (gnome_vfs_file_info_fields_get_type())

GType gnome_vfs_file_permissions_get_type (void);
#define GNOME_VFS_TYPE_VFS_FILE_PERMISSIONS (gnome_vfs_file_permissions_get_type())

GType gnome_vfs_file_info_options_get_type (void);
#define GNOME_VFS_TYPE_VFS_FILE_INFO_OPTIONS (gnome_vfs_file_info_options_get_type())

GType gnome_vfs_set_file_info_mask_get_type (void);
#define GNOME_VFS_TYPE_VFS_SET_FILE_INFO_MASK (gnome_vfs_set_file_info_mask_get_type())

/* enumerations from "gnome-vfs-find-directory.h" */

GType gnome_vfs_find_directory_kind_get_type (void);
#define GNOME_VFS_TYPE_VFS_FIND_DIRECTORY_KIND (gnome_vfs_find_directory_kind_get_type())

/* enumerations from "gnome-vfs-handle.h" */

GType gnome_vfs_open_mode_get_type (void);
#define GNOME_VFS_TYPE_VFS_OPEN_MODE (gnome_vfs_open_mode_get_type())

GType gnome_vfs_seek_position_get_type (void);
#define GNOME_VFS_TYPE_VFS_SEEK_POSITION (gnome_vfs_seek_position_get_type())

/* enumerations from "gnome-vfs-mime-handlers.h" */

GType gnome_vfs_mime_action_type_get_type (void);
#define GNOME_VFS_TYPE_VFS_MIME_ACTION_TYPE (gnome_vfs_mime_action_type_get_type())

GType gnome_vfs_mime_application_argument_type_get_type (void);
#define GNOME_VFS_TYPE_VFS_MIME_APPLICATION_ARGUMENT_TYPE (gnome_vfs_mime_application_argument_type_get_type())

/* enumerations from "gnome-vfs-monitor.h" */

GType gnome_vfs_monitor_type_get_type (void);
#define GNOME_VFS_TYPE_VFS_MONITOR_TYPE (gnome_vfs_monitor_type_get_type())

GType gnome_vfs_monitor_event_type_get_type (void);
#define GNOME_VFS_TYPE_VFS_MONITOR_EVENT_TYPE (gnome_vfs_monitor_event_type_get_type())

/* enumerations from "gnome-vfs-result.h" */

GType gnome_vfs_result_get_type (void);
#define GNOME_VFS_TYPE_VFS_RESULT (gnome_vfs_result_get_type())

/* enumerations from "gnome-vfs-standard-callbacks.h" */

GType gnome_vfs_module_callback_full_authentication_flags_get_type (void);
#define GNOME_VFS_TYPE_VFS_MODULE_CALLBACK_FULL_AUTHENTICATION_FLAGS (gnome_vfs_module_callback_full_authentication_flags_get_type())

/* enumerations from "gnome-vfs-utils.h" */

GType gnome_vfs_make_uri_dirs_get_type (void);
#define GNOME_VFS_TYPE_VFS_MAKE_URI_DIRS (gnome_vfs_make_uri_dirs_get_type())

/* enumerations from "gnome-vfs-volume.h" */

GType gnome_vfs_device_type_get_type (void);
#define GNOME_VFS_TYPE_VFS_DEVICE_TYPE (gnome_vfs_device_type_get_type())

GType gnome_vfs_volume_type_get_type (void);
#define GNOME_VFS_TYPE_VFS_VOLUME_TYPE (gnome_vfs_volume_type_get_type())

/* enumerations from "gnome-vfs-xfer.h" */

GType gnome_vfs_xfer_options_get_type (void);
#define GNOME_VFS_TYPE_VFS_XFER_OPTIONS (gnome_vfs_xfer_options_get_type())

GType gnome_vfs_xfer_progress_status_get_type (void);
#define GNOME_VFS_TYPE_VFS_XFER_PROGRESS_STATUS (gnome_vfs_xfer_progress_status_get_type())

GType gnome_vfs_xfer_overwrite_mode_get_type (void);
#define GNOME_VFS_TYPE_VFS_XFER_OVERWRITE_MODE (gnome_vfs_xfer_overwrite_mode_get_type())

GType gnome_vfs_xfer_overwrite_action_get_type (void);
#define GNOME_VFS_TYPE_VFS_XFER_OVERWRITE_ACTION (gnome_vfs_xfer_overwrite_action_get_type())

GType gnome_vfs_xfer_error_mode_get_type (void);
#define GNOME_VFS_TYPE_VFS_XFER_ERROR_MODE (gnome_vfs_xfer_error_mode_get_type())

GType gnome_vfs_xfer_error_action_get_type (void);
#define GNOME_VFS_TYPE_VFS_XFER_ERROR_ACTION (gnome_vfs_xfer_error_action_get_type())

GType gnome_vfs_xfer_phase_get_type (void);
#define GNOME_VFS_TYPE_VFS_XFER_PHASE (gnome_vfs_xfer_phase_get_type())

G_END_DECLS

#endif /* __LIBGNOMEVFS_ENUM_TYPES_H__ */

/* Generated data ends here */

==> gnome-vfs-2.24.2.tar.bz2: gnome-vfs-2.24.2/libgnomevfs/gnome-vfs-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __LIBGNOMEVFS_ENUM_TYPES_H__
#define __LIBGNOMEVFS_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "gnome-vfs-directory.h" */
GType gnome_vfs_directory_visit_options_get_type (void);
#define GNOME_VFS_TYPE_VFS_DIRECTORY_VISIT_OPTIONS (gnome_vfs_directory_visit_options_get_type())
/* enumerations from "gnome-vfs-file-info.h" */
GType gnome_vfs_file_flags_get_type (void);
#define GNOME_VFS_TYPE_VFS_FILE_FLAGS (gnome_vfs_file_flags_get_type())
GType gnome_vfs_file_type_get_type (void);
#define GNOME_VFS_TYPE_VFS_FILE_TYPE (gnome_vfs_file_type_get_type())
GType gnome_vfs_file_info_fields_get_type (void);
#define GNOME_VFS_TYPE_VFS_FILE_INFO_FIELDS (gnome_vfs_file_info_fields_get_type())
GType gnome_vfs_file_permissions_get_type (void);
#define GNOME_VFS_TYPE_VFS_FILE_PERMISSIONS (gnome_vfs_file_permissions_get_type())
GType gnome_vfs_file_info_options_get_type (void);
#define GNOME_VFS_TYPE_VFS_FILE_INFO_OPTIONS (gnome_vfs_file_info_options_get_type())
GType gnome_vfs_set_file_info_mask_get_type (void);
#define GNOME_VFS_TYPE_VFS_SET_FILE_INFO_MASK (gnome_vfs_set_file_info_mask_get_type())
/* enumerations from "gnome-vfs-find-directory.h" */
GType gnome_vfs_find_directory_kind_get_type (void);
#define GNOME_VFS_TYPE_VFS_FIND_DIRECTORY_KIND (gnome_vfs_find_directory_kind_get_type())
/* enumerations from "gnome-vfs-handle.h" */
GType gnome_vfs_open_mode_get_type (void);
#define GNOME_VFS_TYPE_VFS_OPEN_MODE (gnome_vfs_open_mode_get_type())
GType gnome_vfs_seek_position_get_type (void);
#define GNOME_VFS_TYPE_VFS_SEEK_POSITION (gnome_vfs_seek_position_get_type())
/* enumerations from "gnome-vfs-mime-deprecated.h" */
GType gnome_vfs_mime_action_type_get_type (void);
#define GNOME_VFS_TYPE_VFS_MIME_ACTION_TYPE (gnome_vfs_mime_action_type_get_type())
/* enumerations from "gnome-vfs-mime-handlers.h" */
GType gnome_vfs_mime_application_argument_type_get_type (void);
#define GNOME_VFS_TYPE_VFS_MIME_APPLICATION_ARGUMENT_TYPE (gnome_vfs_mime_application_argument_type_get_type())
/* enumerations from "gnome-vfs-mime-utils.h" */
GType gnome_vfs_mime_equivalence_get_type (void);
#define GNOME_VFS_TYPE_VFS_MIME_EQUIVALENCE (gnome_vfs_mime_equivalence_get_type())
/* enumerations from "gnome-vfs-monitor.h" */
GType gnome_vfs_monitor_type_get_type (void);
#define GNOME_VFS_TYPE_VFS_MONITOR_TYPE (gnome_vfs_monitor_type_get_type())
GType gnome_vfs_monitor_event_type_get_type (void);
#define GNOME_VFS_TYPE_VFS_MONITOR_EVENT_TYPE (gnome_vfs_monitor_event_type_get_type())
/* enumerations from "gnome-vfs-result.h" */
GType gnome_vfs_result_get_type (void);
#define GNOME_VFS_TYPE_VFS_RESULT (gnome_vfs_result_get_type())
/* enumerations from "gnome-vfs-standard-callbacks.h" */
GType gnome_vfs_module_callback_full_authentication_flags_get_type (void);
#define GNOME_VFS_TYPE_VFS_MODULE_CALLBACK_FULL_AUTHENTICATION_FLAGS (gnome_vfs_module_callback_full_authentication_flags_get_type())
GType gnome_vfs_module_callback_full_authentication_out_flags_get_type (void);
#define GNOME_VFS_TYPE_VFS_MODULE_CALLBACK_FULL_AUTHENTICATION_OUT_FLAGS (gnome_vfs_module_callback_full_authentication_out_flags_get_type())
GType gnome_vfs_module_callback_authentication_auth_type_get_type (void);
#define GNOME_VFS_TYPE_VFS_MODULE_CALLBACK_AUTHENTICATION_AUTH_TYPE (gnome_vfs_module_callback_authentication_auth_type_get_type())
/* enumerations from "gnome-vfs-utils.h" */
GType gnome_vfs_make_uri_dirs_get_type (void);
#define GNOME_VFS_TYPE_VFS_MAKE_URI_DIRS (gnome_vfs_make_uri_dirs_get_type())
/* enumerations from "gnome-vfs-volume.h" */
GType gnome_vfs_device_type_get_type (void);
#define GNOME_VFS_TYPE_VFS_DEVICE_TYPE (gnome_vfs_device_type_get_type())
GType gnome_vfs_volume_type_get_type (void);
#define GNOME_VFS_TYPE_VFS_VOLUME_TYPE (gnome_vfs_volume_type_get_type())
/* enumerations from "gnome-vfs-xfer.h" */
GType gnome_vfs_xfer_options_get_type (void);
#define GNOME_VFS_TYPE_VFS_XFER_OPTIONS (gnome_vfs_xfer_options_get_type())
GType gnome_vfs_xfer_progress_status_get_type (void);
#define GNOME_VFS_TYPE_VFS_XFER_PROGRESS_STATUS (gnome_vfs_xfer_progress_status_get_type())
GType gnome_vfs_xfer_overwrite_mode_get_type (void);
#define GNOME_VFS_TYPE_VFS_XFER_OVERWRITE_MODE (gnome_vfs_xfer_overwrite_mode_get_type())
GType gnome_vfs_xfer_overwrite_action_get_type (void);
#define GNOME_VFS_TYPE_VFS_XFER_OVERWRITE_ACTION (gnome_vfs_xfer_overwrite_action_get_type())
GType gnome_vfs_xfer_error_mode_get_type (void);
#define GNOME_VFS_TYPE_VFS_XFER_ERROR_MODE (gnome_vfs_xfer_error_mode_get_type())
GType gnome_vfs_xfer_error_action_get_type (void);
#define GNOME_VFS_TYPE_VFS_XFER_ERROR_ACTION (gnome_vfs_xfer_error_action_get_type())
GType gnome_vfs_xfer_phase_get_type (void);
#define GNOME_VFS_TYPE_VFS_XFER_PHASE (gnome_vfs_xfer_phase_get_type())
G_END_DECLS

#endif /* __LIBGNOMEVFS_ENUM_TYPES_H__ */

/* Generated data ends here */
